==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/GetBucketCorsResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetBucketCorsResponse(
    corsRules: Optional[Iterable[zio.aws.s3.model.CORSRule]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketCorsResponse = {
    import GetBucketCorsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
      .builder()
      .optionallyWith(
        corsRules.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.corsRules)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.GetBucketCorsResponse.ReadOnly =
    zio.aws.s3.model.GetBucketCorsResponse.wrap(buildAwsValue())
}
object GetBucketCorsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketCorsResponse =
      zio.aws.s3.model.GetBucketCorsResponse(
        corsRules.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def corsRules: Optional[List[zio.aws.s3.model.CORSRule.ReadOnly]]
    def getCorsRules
        : ZIO[Any, AwsError, List[zio.aws.s3.model.CORSRule.ReadOnly]] =
      AwsError.unwrapOptionField("corsRules", corsRules)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
  ) extends zio.aws.s3.model.GetBucketCorsResponse.ReadOnly {
    override val corsRules: Optional[List[zio.aws.s3.model.CORSRule.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.corsRules())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.s3.model.CORSRule.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
  ): zio.aws.s3.model.GetBucketCorsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/GetBucketCorsResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetBucketCorsResponse(
    corsRules: Option[Iterable[zio.aws.s3.model.CORSRule]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketCorsResponse = {
    import GetBucketCorsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
      .builder()
      .optionallyWith(
        corsRules.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.corsRules)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.GetBucketCorsResponse.ReadOnly =
    zio.aws.s3.model.GetBucketCorsResponse.wrap(buildAwsValue())
}
object GetBucketCorsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketCorsResponse =
      zio.aws.s3.model.GetBucketCorsResponse(
        corsRules.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def corsRules: Option[List[zio.aws.s3.model.CORSRule.ReadOnly]]
    def getCorsRules
        : ZIO[Any, AwsError, List[zio.aws.s3.model.CORSRule.ReadOnly]] =
      AwsError.unwrapOptionField("corsRules", corsRules)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
  ) extends zio.aws.s3.model.GetBucketCorsResponse.ReadOnly {
    override val corsRules: Option[List[zio.aws.s3.model.CORSRule.ReadOnly]] =
      scala
        .Option(impl.corsRules())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.s3.model.CORSRule.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketCorsResponse
  ): zio.aws.s3.model.GetBucketCorsResponse.ReadOnly = new Wrapper(impl)
}
